Defining your own Classes
:::::::::::::::::::::::::

.. toctree::
   :caption: Defining your own Classes
   :maxdepth: 2

   intro-ClassesandObjectstheBasics.rst
   ObjectsRevisited.rst
   UserDefinedClasses.rst
   ImprovingourConstructor.rst
   AddingOtherMethodstoourClass.rst
   ObjectsasArgumentsandParameters.rst
   ConvertinganObjecttoaString.rst
   InstancesasReturnValues.rst
   sorting_instances.rst
   ClassVariablesInstanceVariables.rst
   PrivateInstanceVariables.rst
   ThinkingAboutClasses.rst
   TestingClasses.rst
   Tamagotchi.rst
   ClassDecorators.rst
   Glossary.rst
   Exercises.rst
   ChapterAssessment.rst
